@@ -42,8 +42,11 @@ class GitRecipe(object):
             raise zc.buildout.UserError('Can not find repository name')
         self.options['location'] = os.path.join(buildout['buildout']['parts-directory'], self.repo_path)
         self.paths = options.get('paths', None)
-        if buildout['buildout'].get('offline') == 'true':
+        if buildout['buildout'].get('offline').lower() == 'true':
+            self.update = lambda: ()
+        if self.options.get('newest', 'true').lower() == 'false': 
             self.install = lambda: ()
+            self.update = lambda: ()
 
     def git(self, operation, args, quiet=True):
         if quiet:
